@@ -35,7 +35,7 @@ class SessionAlreadyOpen(Exception):
         self.session = session
 
 
-class Session(object):
+class Session:
     def __enter__(self) -> "Session":
         return self
 
@@ -69,12 +69,14 @@ class Session(object):
         raise NotImplementedError(self.check_output)
 
     def Popen(
-        self, argv, cwd: Optional[str] = None, user: Optional[str] = None, **kwargs
+        self, argv, cwd: Optional[str] = None, user: Optional[str] = None,
+        **kwargs
     ):
         raise NotImplementedError(self.Popen)
 
     def call(
-        self, argv: List[str], cwd: Optional[str] = None, user: Optional[str] = None
+        self, argv: List[str], cwd: Optional[str] = None,
+        user: Optional[str] = None
     ):
         raise NotImplementedError(self.call)
 
@@ -114,10 +116,12 @@ class SessionSetupFailure(Exception):
         self.errlines = errlines
 
 
-def run_with_tee(session: Session, args: List[str], **kwargs):
+def run_with_tee(session: Session,
+                 args: List[str], **kwargs) -> Tuple[int, List[str]]:
     if "stdin" not in kwargs:
         kwargs["stdin"] = subprocess.DEVNULL
-    p = session.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, **kwargs)
+    p = session.Popen(
+        args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, **kwargs)
     contents = []
     while p.poll() is None:
         line = p.stdout.readline()
@@ -128,7 +132,8 @@ def run_with_tee(session: Session, args: List[str], **kwargs):
 
 
 def get_user(session):
-    return session.check_output(["sh", "-c", "echo $USER"], cwd="/").decode().strip()
+    return session.check_output(
+        ["sh", "-c", "echo $USER"], cwd="/").decode().strip()
 
 
 def which(session, name):
